# Data Overview
This map shows a curated subset of the most-used OOI instruments from 
the Coastal Endurance and Axial Seamount arrays. Note that this is only the 
data available via the M2M interface so it does not include more complex 
data streams like acoustic/seismic and camera/video data. 

Just below the map is a search bar and a table. You can use the search bar 
to narrow down the subset of instruments displayed in the table. Each row 
of the table has a checkbox on the left-most side of the row. You can click 
one or more of those to highlight specific instruments on the map. 

You can pan and zoom on this map and you can 
also click on the points to get some information about the instrument. 

<iframe width="100%" height="910" frameborder="0"
  src="https://observablehq.com/embed/78494d8e7d104e96@167?cells=viewof+map%2Cviewof+search%2Cviewof+rows"></iframe>
